@@ -465,15 +465,6 @@ class OpenStackComputeShell(object):
             default=utils.env('NOVA_SERVICE_NAME'),
             help=_('Defaults to env[NOVA_SERVICE_NAME].'))
 
-        parser.add_argument(
-            '--volume-service-name',
-            action=DeprecatedAction,
-            metavar='<volume-service-name>',
-            default=utils.env('NOVA_VOLUME_SERVICE_NAME'),
-            use=_('This option will be removed after Nova 15.0.0 is '
-                  'released.'),
-            help=argparse.SUPPRESS)
-
         parser.add_argument(
             '--os-endpoint-type',
             metavar='<endpoint-type>',
@@ -514,6 +505,7 @@ class OpenStackComputeShell(object):
         if osprofiler_profiler:
             parser.add_argument('--profile',
                                 metavar='HMAC_KEY',
+                                default=utils.env('OS_PROFILE'),
                                 help='HMAC key to use for encrypting context '
                                 'data for performance profiling of operation. '
                                 'This key should be the value of the HMAC key '
